@@ -15,8 +15,10 @@ try:
 
     from .logs.log_data import LogData
 
+
 except ModuleNotFoundError:
-    from logs.setup_module import Setup
+
+    from .logs.setup_module import Setup 
     setup = Setup()
 
 
